@@ -6,12 +6,9 @@ library(PKNCA)
 library(dplyr, quietly=TRUE)
 
 ## Load the PK concentration data
-d_conc <-
-  as.data.frame(datasets::Theoph) %>%
-  mutate(Subject=as.numeric(as.character(Subject)))
+d_conc <- datasets::Theoph
 ## Generate the dosing data
 d_dose <- d_conc[d_conc$Time == 0,]
-d_dose$Time <- 0
 
 ## Create a concentration object specifying the concentration, time, and
 ## subject columns.  (Note that any number of grouping levels is
